Song tempo (BPM) data
Format
dataframe with one row for each song with a personally-measured tempo reading.
- title
The name of the song
- tempo_bpm
Tempo, in beats per minute, measured personally by Alex Mitrani
Provenance
Raw-hand-curated, from inst/extdata/song_tempo_bpm_data.csv. Read as-is by Repeatr_1, no transformation. Not exported to fugazibase - kept in Repeatr only, for its own Shiny app.
Examples
song_tempo_bpm_data
#> title tempo_bpm
#> 1 23 beats off 110.0
#> 2 and the same 148.5
#> 3 argument 102.0
#> 4 arpeggiator 179.0
#> 5 back to base 194.0
#> 6 bad mouth 95.5
#> 7 bed for the scraping 93.5
#> 8 birthday pony 102.5
#> 9 blueprint 102.0
#> 10 break 132.0
#> 11 break-in 212.0
#> 12 brendan #1 132.0
#> 13 bulldog front 140.0
#> 14 burning 144.0
#> 15 burning too 95.0
#> 16 by you 66.0
#> 17 cashout 112.0
#> 18 cassavetes 105.0
#> 19 caustic acrostic 170.0
#> 20 closed captioned 138.0
#> 21 combination lock 103.0
#> 22 dear justice letter 129.0
#> 23 do you like me 150.0
#> 24 downed city 179.0
#> 25 epic problem 179.0
#> 26 exit only 157.0
#> 27 ex-spectator 123.0
#> 28 facet squared 148.0
#> 29 fd 87.0
#> 30 fell, destroyed 116.0
#> 31 five corporations 121.0
#> 32 floating boy 115.0
#> 33 foreman's dog 142.0
#> 34 forensic scene 80.0
#> 35 full disclosure 155.0
#> 36 furniture 98.0
#> 37 give me the cure 150.0
#> 38 glueman 112.0
#> 39 great cop 163.0
#> 40 greed 143.0
#> 41 guilford fall 143.0
#> 42 hello morning 190.0
#> 43 in defense of humans 91.0
#> 44 instrument 60.0
#> 45 joe #1 86.0
#> 46 kyeo 206.0
#> 47 last chance for a slow dance 116.0
#> 48 latest disgrace 123.0
#> 49 latin roots 154.0
#> 50 life and limb 145.0
#> 51 lockdown 146.0
#> 52 long distance runner 129.0
#> 53 long division 134.0
#> 54 margin walker 153.0
#> 55 merchandise 198.0
#> 56 nice new outfit 165.0
#> 57 nightshop 162.0
#> 58 no surprise 78.0
#> 59 number 5 176.0
#> 60 oh 163.0
#> 61 pink frosty 89.0
#> 62 place position 149.0
#> 63 polish 142.0
#> 64 promises 130.0
#> 65 provisional 152.0
#> 66 public witness program 193.0
#> 67 recap modotti 70.0
#> 68 reclamation 137.0
#> 69 rend it 120.0
#> 70 repeater 136.0
#> 71 reprovisional 145.0
#> 72 returning the screw 110.0
#> 73 runaway return 128.0
#> 74 shut the door 132.0
#> 75 sieve-fisted find 144.0
#> 76 smallpox champion 174.0
#> 77 song #1 108.0
#> 78 stacks 149.0
#> 79 steady diet 150.0
#> 80 strangelight 103.0
#> 81 styrofoam 185.0
#> 82 suggestion 90.0
#> 83 sweet and low 106.0
#> 84 target 161.0
#> 85 the kill 60.0
#> 86 the word 97.0
#> 87 turn off your guns 100.0
#> 88 turnover 140.0
#> 89 two beats off 89.0
#> 90 version 48.0
#> 91 waiting room 103.0
#> 92 walken's syndrome 163.0