sweepstack runs stacks iteratively over a range of different starting shows.
Source:R/sweepstack.R
sweepstack.Rdit returns a dataframe with two columns, "gid" and "shows". gid is the gig id of the starting show used for the test. shows is the number of shows included in the resulting stack.
Usage
sweepstack(
number_stacks = NULL,
exclude_poor_sound_quality = FALSE,
myduration_data_da = NULL,
mysummary = NULL,
myothervariables = NULL,
mygidsoundquality = NULL
)Arguments
- number_stacks
this is the number of starting shows to test. if not specified all the possible starting shows will be tested.
- exclude_poor_sound_quality
set this to TRUE to exclude shows with sound quality rated as 'Poor'.
- myduration_data_da
optional
duration_data_dadataframe (as produced byRepeatr_1()) to be used for the pool of shows/songs to sweep over. If omitted the currently lazy-loaded default will be used.- mysummary, myothervariables, mygidsoundquality
optional lookup tables passed straight through to
stacks()- see there for details. If omitted the currently lazy-loaded defaults will be used.